@@ -140,7 +140,7 @@ $LANG_LINKS_ADMIN = array(
     24 => 'Link not found',
     25 => 'The link you selected for editing could not be found.',
     26 => 'Validate Links',
-    27 => 'HTML Status',
+    27 => 'HTTP Status',
     28 => 'Edit category',
     29 => 'Enter or edit the details below.',
     30 => 'Category',
