@@ -144,7 +144,7 @@ $LANG_LINKS_ADMIN = array(
     24 => 'Ne najdem povezave',
     25 => 'Povezava, izbrana za urejanje, ni bila najdena.',
     26 => 'Preveri povezave',
-    27 => 'HTML stanje',
+    27 => 'HTTP stanje',
     28 => 'Uredi kategorijo',
     29 => 'Vnesi ali uredi spodnje podrobnosti.',
     30 => 'Kategorija',
