@@ -278,7 +278,7 @@ function INST_installEngine($install_type, $install_step)
             require_once $_CONF['path_system'] . 'lib-database.php';
 
             $req_string = 'index.php?mode=' . $install_type
-                        . '&step=3&dbconfig_path=' . $dbconfig_path
+                        . '&step=3&dbconfig_path=' . urlencode($dbconfig_path) // bug fix
                         . '&install_plugins=' . $install_plugins
                         . '&language=' . $language
                         . '&site_name=' . urlencode($site_name)
@@ -354,7 +354,7 @@ function INST_installEngine($install_type, $install_step)
                               . '<p>' . $LANG_INSTALL[91] . '</p>';
                 } else {
 
-                    $old_versions = array('1.2.5-1','1.3','1.3.1','1.3.2','1.3.2-1','1.3.3','1.3.4','1.3.5','1.3.6','1.3.7','1.3.8','1.3.9','1.3.10','1.3.11','1.4.0','1.4.1','1.5.0','1.5.1','1.5.2','1.6.0','1.6.1');
+                    $old_versions = array('1.2.5-1','1.3','1.3.1','1.3.2','1.3.2-1','1.3.3','1.3.4','1.3.5','1.3.6','1.3.7','1.3.8','1.3.9','1.3.10','1.3.11','1.4.0','1.4.1','1.5.0','1.5.1','1.5.2','1.6.0','1.6.1','1.7.0','1.7.1');
                     if (empty($curv)) {
                         // If we were unable to determine the current GL
                         // version is then ask the user what it is
@@ -531,7 +531,7 @@ function INST_installEngine($install_type, $install_step)
 
                         INST_setVersion($siteconfig_path);
 
-                        if (! $install_plugins) {
+                        if (! $install_plugins) { 
                             // do a default install of all available plugins
 
                             /**
@@ -551,11 +551,11 @@ function INST_installEngine($install_type, $install_step)
                             $language = $lx_inst;
 
                             INST_defaultPluginInstall();
-                        }
 
                         require_once 'LocalizeGeeklog.php';
                         $obj = new LocalizeGeeklog('ja');
                         $obj->execute();
+                        }
 
                         // Installation is complete. Continue onto either
                         // custom plugin installation page or success page
@@ -1042,7 +1042,6 @@ if (INST_phpOutOfDate()) {
 
         $display .= '<h1 class="heading">' . $LANG_INSTALL[3] . '</h1>' . LB;
 
-//      if (!file_exists($gl_path . $dbconfig_file) && !file_exists($gl_path . 'public_html/' . $dbconfig_file)) {
         require_once $siteconfig_path; // We need siteconfig.php for core $_CONF['path'] values.
         if (!file_exists($gl_path . $dbconfig_file) && !file_exists($gl_path . 'public_html/' . $dbconfig_file)
                                                     && !file_exists($_CONF['path'] . $dbconfig_file)) {
@@ -1054,9 +1053,6 @@ if (INST_phpOutOfDate()) {
             $num_errors++;
         } else {
             // See whether the file/directory is located in the default place or in public_html
-//          $dbconfig_path = file_exists($gl_path . $dbconfig_file)
-//                              ? $gl_path . $dbconfig_file
-//                              : $gl_path . 'public_html/' . $dbconfig_file;
             if (file_exists($gl_path . $dbconfig_file)) {
                 $dbconfig_path = $gl_path . $dbconfig_file;
             } else if (file_exists($gl_path . 'public_html/' . $dbconfig_file)) {
